==========
mangoutils
==========


Submodules
==========
* web: utility classes for handling urls, list of well known cdns, top level domains
* html: utility class for parsing html and accessing elements via xpath


Download
========

* PyPI: http://pypi.python.org/pypi/mangoutils/
* Source: https://github.com/amol9/mangoutils/

